<?php

/**
 * @file
 * Page callbacks and admin forms of floodcontrol_settings_api module.
 */

/**
 * Page callback for floodcontrol_settings_api settings form.
 */
function floodcontrol_settings_api_form($form, &$form_state) {

  $form = array();
  // This empty array will be filled with other modules who implement the hook.
  $form = module_invoke_all('floodcontrol_settings', $form);
  if (empty($form)) {
    return $form;
  }
  else {
    return system_settings_form($form);
  }
}

/**
 * Callback function for admin/config/system/floodcontrol-settings-api.
 *
 * Display the settings form.
 */
function floodcontrol_settings_page() {
  $output = array(
    'intro' => array(
      '#type' => 'item',
      '#title' => t('Flood Control API - Settings'),
      '#markup' => 'If floodcontrol_api_settings API is implemented in your custom module, '
      . 'then your custom form settings appear here. Further details given in README.txt',
    ),
    'settings_form' => drupal_get_form('floodcontrol_settings_api_form'),
  );

  return $output;
}

/**
 * Callback function for admin/config/system/floodcontrol-settings-api.
 *
 * Display the settings form.
 */
function floodcontrol_floodclear_page() {
  $output = array(
    'intro' => array(
      '#type' => 'item',
      '#title' => t('Flood Control API - Clear flood'),
      '#markup' => 'Click on the submit button to clear the flood table. WARNING: '
      . 'This will unblock all the users. @TODO: Add event and identified based unblocking.',
    ),
    'floodclear_form' => drupal_get_form('floodclear_form'),
  );

  return $output;
}

/**
 * Floodcontrol form.
 *
 * This form will show will enable to clear the
 * flood table.
 *
 * @see floodclear_form_submit()
 */
function floodclear_form($form, &$form_state) {
  $form = array();
  $form['actions']['delete'] = array(
    '#type' => 'submit',
    '#value' => t('Delete'),
  );
  return $form;
}

/**
 * Submit function for floodclear_form().
 *
 * Adds a submit handler/function to our form to redirect
 * the user to a confirmation page.
 */
function floodclear_form_submit($form, &$form_state) {
  $form_state['redirect'] = '/admin/config/system/floodcontrol-settings-api/clear-flood/bulk';
}

/**
 * A form generated with confirm_form for bulk delete().
 *
 * This function generates the confirmation form using the confirm_form()
 */
function flood_bulk_delete_confirm_form($form, &$form_state) {
  $desc = t('The flood table will be truncated');
  return confirm_form($form, t('Are you sure?'), 'admin/config/system/floodcontrol-settings-api/clear-flood', $desc, 'Continue', t('Cancel'));
}

/**
 * Submit function for flood_bulk_delete_confirm_form().
 *
 * Adds a submit handler/function to our form to redirect
 * the user to a floodcontrol settings page.
 */
function flood_bulk_delete_confirm_form_submit($form, &$form_state) {

  $num_deleted = db_truncate('flood')
    ->execute();
  drupal_set_message("The flood table has been cleared.");
  drupal_goto("admin/config/system/floodcontrol-settings-api/clear-flood");
}
